==> nextcloud-app-calendar-1%3A4.3.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Calendar" : "Kalendar",
    "Appointments" : "Takime",
    "Confirm" : "Konfirmo",
    "Where:" : "Ku:",
    "New event" : "Veprimtari e re",
    "Today" : "Sot",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "List" : "List",
    "Preview" : "Parapamje ",
    "Copy link" : "Kopjo linkun",
    "Edit" : "Përpuno",
    "Delete" : "Fshije",
    "New calendar" : "Kalendar i ri",
    "Export" : "Eksport",
    "Name" : "Emri",
    "Deleted" : "E fshirë",
    "Restore" : "Rikthe",
    "Delete permanently" : "Fshije përgjithmonë",
    "Share link" : "Ndani lidhjen",
    "can edit" : "mund të përpunojnë",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "Filename" : "Emri i skedarit",
    "Cancel" : "Anuloje",
    "Automatic" : "Automatike",
    "List view" : "Pamje listë",
    "Actions" : "Veprimet",
    "Show week numbers" : "Shfaq numra javësh",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Duration" : "Kohëzgjatja",
    "to" : "te",
    "Add" : "Shto",
    "Monday" : "E hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Sunday" : "E dielë",
    "Save" : "Ruaj",
    "Update" : "Përditësoje",
    "Your email address" : "Adresa juaj email",
    "Notification" : "Njoftim",
    "Email" : "Emaili",
    "Delete file" : "Fshi skedarin",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Available" : "i disponueshëm",
    "Unknown" : "I/E panjohur",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Tentative" : "Tentativë",
    "Send email" : "Dërgo email",
    "All day" : "Gjithë ditën",
    "Repeat" : "Përsërite",
    "never" : "kurrë",
    "after" : "pas",
    "available" : "në gjëndje",
    "More" : "Më tepër",
    "Global" : "Globale",
    "Personal" : "Personale",
    "Details" : "Detajet",
    "Attendees" : "Pjesëmarrës",
    "Resources" : "Burimet",
    "Close" : "Mbylle",
    "Anniversary" : "Përvjetor",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "Prev" : "I mëparshëm",
    "Next" : "Tjetër",
    "Other" : "Tjetër",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Status" : "Status",
    "Confirmed" : "E konfirmuar",
    "Canceled" : "Anuluar",
    "Categories" : "Kategoritë",
    "Presentation" : "Paraqitje",
    "Office" : "Zyrë",
    "Mail" : "Posta",
    "Birthday" : "Datëlindje"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A4.4.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/calendar/l10n/sq.js <==
OC.L10N.register(
    "calendar",
    {
    "%s has published the calendar »%s«" : "%s ka publikuar kalendarin %s",
    "Hello," : "Përshëndetje,",
    "We wanted to inform you that %s has published the calendar »%s«." : "Donim t'ju informonim se %s ka publikuar kalendarin »%s«",
    "Open »%s«" : "Hap »%s«",
    "Cheers!" : "Gëzuar!",
    "Calendar" : "Kalendar",
    "Appointments" : "Takime",
    "Confirm" : "Konfirmo",
    "Where:" : "Ku:",
    "New event" : "Veprimtari e re",
    "Today" : "Sot",
    "Day" : "Ditë",
    "Week" : "Javë",
    "Month" : "Muaj",
    "List" : "List",
    "Preview" : "Parapamje ",
    "Copy link" : "Kopjo linkun",
    "Edit" : "Përpuno",
    "Delete" : "Fshije",
    "New calendar" : "Kalendar i ri",
    "Export" : "Eksport",
    "Name" : "Emri",
    "Deleted" : "E fshirë",
    "Restore" : "Rikthe",
    "Delete permanently" : "Fshije përgjithmonë",
    "Copy internal link" : "Kopjoni lidhjen e brendshme",
    "Share link" : "Ndani lidhjen",
    "can edit" : "mund të përpunojnë",
    "Share with users or groups" : "Nda me përdoruesit ose grupet",
    "Save" : "Ruaj",
    "Filename" : "Emri i skedarit",
    "Cancel" : "Anuloje",
    "Automatic" : "Automatike",
    "List view" : "Pamje listë",
    "Actions" : "Veprimet",
    "Show week numbers" : "Shfaq numra javësh",
    "Location" : "Vendndodhje",
    "Description" : "Përshkrim",
    "Duration" : "Kohëzgjatja",
    "to" : "te",
    "Add" : "Shto",
    "Monday" : "E hënë",
    "Tuesday" : "E martë",
    "Wednesday" : "E mërkurë",
    "Thursday" : "E enjte",
    "Friday" : "E premte",
    "Saturday" : "E shtunë",
    "Sunday" : "E dielë",
    "Update" : "Përditësoje",
    "Your email address" : "Adresa juaj email",
    "Notification" : "Njoftim",
    "Email" : "Emaili",
    "Delete file" : "Fshi skedarin",
    "Choose a file to add as attachment" : "Zgjidhni një kartelë që të shtohet si bashkëngjitje",
    "Available" : "i disponueshëm",
    "Unknown" : "I/E panjohur",
    "Accept" : "Prano",
    "Decline" : "Refuzo",
    "Tentative" : "Tentativë",
    "Send email" : "Dërgo email",
    "All day" : "Gjithë ditën",
    "Repeat" : "Përsërite",
    "never" : "kurrë",
    "after" : "pas",
    "available" : "në gjëndje",
    "More" : "Më tepër",
    "Global" : "Globale",
    "Subscribe" : "Abonohu",
    "Personal" : "Personale",
    "Details" : "Detajet",
    "Attendees" : "Pjesëmarrës",
    "Resources" : "Burimet",
    "Close" : "Mbylle",
    "Anniversary" : "Përvjetor",
    "Week {number} of {year}" : "Java e {number} e {year}",
    "Daily" : "Përditë",
    "Weekly" : "Çdo javë",
    "Other" : "Tjetër",
    "When shared show full event" : "Kur ndahet shfaqje e veprimtarisë së plotë",
    "When shared show only busy" : "Kur ndahet shfaqje vetëm i zënë",
    "When shared hide this event" : "Kur ndahet fshihe këtë veprimtari",
    "Status" : "Status",
    "Confirmed" : "E konfirmuar",
    "Canceled" : "Anuluar",
    "Categories" : "Kategoritë",
    "Presentation" : "Paraqitje",
    "Office" : "Zyrë",
    "Mail" : "Posta",
    "Birthday" : "Datëlindje"
},
"nplurals=2; plural=(n != 1);");
